{--

  Check that the minimum and maximum number of papers
  assigned to a referee are within one of each other.

--}

define element conference {
  element paper *
}

define element paper {
  element title { xsd:string } ,
  element authors { xsd:string } ,
  element referee { xsd:string } *
}

define element referees {
  element referee {
    attribute count { xsd:int } ,
    xsd:string
  } *
}

define function referee-counts(
  element conference $conf
) returns element referees {
  <referees>{
    for $r in distinct-values($conf/paper/referee)
    return
      let $c :=
        count(
          for $p in $conf/paper
          where $p/referee = $r
          return $p
        )
      return
        <referee count="{$c}">{ data($r) }</referee>
  }</referees>
}

let
  $conf := treat as document conference ( document("conference.xml") ) ,
  $refs := referee-counts($conf/conference) ,
  $counts := for $count in $refs/referee/@count return data($count) ,
  $min := min-int($counts) ,
  $max := max-int($counts)
return
  $max - $min <= 1
  





