{--

  Rename title and authors to title-i and author-i,
  where i is the paper number.

--}

define element conference {
  element paper {
    element title { xsd:string } ,
    element authors { xsd:string } ,
    element referee { xsd:string } *
  } *
}

define element referees {
  element referee {
    element source { xsd:string } ,
    element target { xsd:string }
  }
}

define element referee { xsd:string }

define element target { xsd:string }

define function int-to-string(
  xsd:int $i
) returns xsd:string {
  string-value( <dummy>{ $i }</dummy> )
}

define function rename-referee(
  element referee $ref ,
  element referees $refs
) returns element referee {
  <referee>{
    data(treat as element target ( $refs/referee[source = $ref]/target ))
  }</referee>
}

define function rename(
  element conference $conf ,
  element referees $refs
) returns element conference {
  <conference>{
    for $paper in $conf/paper
    let $i := int-to-string(index-of($conf/paper, $paper))
    return
      <paper>
        <title>{ concat("title-", $i) }</title>
        <authors>{ concat("authors-", $i) }</authors>
        { for $ref in $paper/referee return rename-referee($ref, $refs) }
      </paper>
  }</conference>
}

let
  $conf := treat as document conference ( document("conference.xml") ) ,
  $refs := treat as document referees ( document("referees.xml") )
return
  rename($conf/conference, $refs/referees)





